module.exports = defineTest({
	description: 'handles accessing funciton return values in deoptimized conditionals'
});
